#
# spec file for package python-papermill
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-papermill
Version:        2.6.0
Release:        1.3
Summary:        Tool to parametrize and run Jupyter and nteract Notebooks
License:        BSD-3-Clause
URL:            https://github.com/nteract/papermill
Source:         https://files.pythonhosted.org/packages/source/p/papermill/papermill-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-ansicolors
Requires:       python-click
Requires:       python-entrypoints
Requires:       python-nbclient >= 0.2.0
Requires:       python-nbformat >= 5.2.0
Requires:       python-requests >= 2.21.0
Requires:       python-tenacity >= 5.0.2
Requires:       python-tqdm >= 4.32.2
%if 0%{?python_version_nodots} >= 312
Requires:       python-aiohttp
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-azure-datalake-store >= 0.0.30
Recommends:     python-azure-identity >= 1.3.1
Recommends:     python-azure-storage-blob >= 12.1.0
Recommends:     python-black
Recommends:     python-boto3
Recommends:     python-gcsfs >= 0.2.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module aiohttp if %python-base >= 3.12}
BuildRequires:  %{python_module ansicolors}
BuildRequires:  %{python_module azure-datalake-store >= 0.0.30}
BuildRequires:  %{python_module azure-identity >= 1.3.1}
BuildRequires:  %{python_module azure-storage-blob >= 12.1.0}
BuildRequires:  %{python_module boto3}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module entrypoints}
BuildRequires:  %{python_module gcsfs}
# for python-azure-storage-blob (https://build.opensuse.org/request/show/1083380#comments)
BuildRequires:  %{python_module typing_extensions}
BuildRequires:  %{python_module ipython >= 5.0}
BuildRequires:  %{python_module ipywidgets}
BuildRequires:  %{python_module moto}
BuildRequires:  %{python_module nbclient >= 0.2.0}
BuildRequires:  %{python_module nbformat >= 5.2}
BuildRequires:  %{python_module notebook}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pyarrow}
BuildRequires:  %{python_module pytest-env}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.21.0}
BuildRequires:  %{python_module tenacity >= 5.0.2}
BuildRequires:  %{python_module tqdm >= 4.32.2}
# /SECTION
%python_subpackages

%description
Papermill is a tool for parameterizing, executing,
and analyzing Jupyter Notebooks.

%prep
%autosetup -p1 -n papermill-%{version}
# docs subfolder not in sdist https://github.com/nteract/papermill/issues/737
sed -i '/docs_/d' setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/papermill
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# different output type expected
donttest="TestBrokenNotebook2"
%pytest -k "not ($donttest)"

%post
%python_install_alternative papermill

%postun
%python_uninstall_alternative papermill

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/papermill
%{python_sitelib}/papermill
%{python_sitelib}/papermill-%{version}.dist-info

%changelog
* Sat Jul 13 2024 Ben Greiner <code@bnavigator.de>
- Update to 2.6.0
  * bring back strip_color and remove ANSI color codes from
    exception traceback #791
  * cleaned up documentation #790
  * prevent error override, fix traceback type #788
  * Upgrade tests to moto v5 #779
  * raise PapermillExecutionError when CellExecutionError is raised
    without cell error output #786
  * make progress_bar param accept a dict #778
  * Fix nbformat to 5.2.0 to cell None type #770
  * Use f-strings where possible #762
  * Unmark wheel as universal #764
- Drop papermill-pr779-moto5.patch
* Fri Mar  8 2024 Ben Greiner <code@bnavigator.de>
- Skip testing python39: no longer supported since ipython 8.19
* Wed Feb 14 2024 Ben Greiner <code@bnavigator.de>
- Add papermill-pr779-moto5.patch gh#nteract/papermill#779
* Thu Dec 28 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.5.0
  * Added support for python 3.11 and 3.12 PR #733
  * Dropped support for 3.7
  * ABS added support for using a Service principle via EnvCreds PR
    [#728]
  * Added “github” extra deps. to the “all” extra PR #715
  * Added a warning if non set parameter is passed through CLI PR
    [#701]
  * Skip black formatting when encountering attribute errors PR
    [#699]
  * Removed forced deepcopy of notebook objects PR #694
  * Always update notebook version on execute PR #691
  * Set minimum version for tenacity PR #682
  * Removed use of ansiwrap PR #681
* Sat Apr 29 2023 Ben Greiner <code@bnavigator.de>
- Add typing extensions if azuore-storage-blob
- Don't skip pyarrow tests anymore
* Sun Jan  8 2023 Ben Greiner <code@bnavigator.de>
- Update to 2.4.0
  * Add tracking cell executions with cell descriptions PR #650
  * Fixed Azure Blob URI matching for prefixes PR #654
  * Updates HDFS handler to use PyArrow.fs.HadoopFileSystm PR #658
  * Drop support for Python 3.6 PR #666
  * CI Build fixes PR #664
  * Updated mock references in tests PR #668
  * Added option for not writing any output ipynb file PR #669
  * Allow custom kernel name and language in engine registration PR
    [#676]
  * Allow for direct input of NotebookNode objects PR #670
  * Removed deepcopy of input nodes PR #673
  * Fixed failing tests for windows PR #672
  * Implemented bash translator PR #674
- Drop patches
  * papermill-fix-test.patch
  * python-papermill-no-mock.patch
* Fri Jun 17 2022 pgajdos@suse.com
- don't use python-mock: upstream pull request instead of sed
- added patches
  fix https://github.com/nteract/papermill/pull/668
  + python-papermill-no-mock.patch
* Wed Apr  6 2022 pgajdos@suse.com
- do not require python-mock for build
* Mon Feb 28 2022 Ben Greiner <code@bnavigator.de>
- Update to v2.3.4
  * Add read handler for GitHub notebooks PR #622
  * Add cell description to tqdm PR #565
  * Update builds for python 3.9 and 3.10
  * Update file read to not fail early with boto empty file
    exception PR #614
  * Support new version of gcsfs PR #624
  * Fix an issue where the PapermillExecutionError can be pickled
    but will not be unpicklable PR #629
  * Update documentation build and theme
  * Remove deprecated pyarrow.hdfs.connect call from iorw.py
  * Remove support for python 3.5
- Drop papermill-pr624-gcsfs.patch merged upstream
- Add papermill-fix-test.patch
* Sun Sep 19 2021 Ben Greiner <code@bnavigator.de>
- Add papermill-pr624-gcsfs.patch -- gh#nteract/papermill#624
* Sat Apr 10 2021 Ben Greiner <code@bnavigator.de>
- Update to 2.3.3
  * Fixed language check to catch non-v3-backwards compatible
    notebook specs
  * Builds updated for python 3.6.12 / travis support
  * README updated to reflect supported python versions
- release 2.3.2
  * Fixed code of conduct link
  * Fixed codify for matlab kernels
  * Added support for sparkmagic kernels
- release 2.3.1
  * Added minimum version pin for nbformat
- release 2.3.0
  * Notebooks that are loaded with papermill now upgrade the
    document to the latest spec version (to support cell-id
    assignments).
  * Empty yaml files are now accepted as parameter files
  * Binder typo fix for example notebook
  * Entry point documentation improvements
  * Code of Conduct documentation link cleanup
  * Tox change for local doc builds
- release 2.2.1
  * Allow `pathlib.Path`s in `execute_notebook` and
    `inspect_notebook`
- release 2.2.0
  * Provide help for Python notebooks by inspecting the
    `parameters` cell, via `--help-notebook`
  * Support added for parameterizing Powershell kernels
- release 2.1.3
  * Removed jupyter_client dependency in requirements to avoid
    confusing pip on the actual version requirements.
  * Parameterized commenting so that once can pass a `comment`
    argument to assign the comment string in injected cells.
- release 2.1.2
  * Expand Usage Docs for JupyterLab
  * Support `nan` and `inf` in Python translator
  * Added fix for required async loop registration in python 38 on
    windows
- Skip python36: no python36-pandas on TW
* Tue Jun  9 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1.1:
  * Support for python 3.5 has been dropped
  * Error cells injected at the top of failed notebooks look nicer now as markdown.
  * DeadKernelExceptions, usually from OOM, now exit with a status code of 138 from the CLI.
  * Error cell at the top of failed notebook has been made better. It now also has a link to an injected cell where the error occurred.
  * Updated a deprecated function to the new function name for nbclient dependency.
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Remove py2 code as upstream says it is py3 only compatible
* Mon Feb 24 2020 Todd R <toddrme2178@gmail.com>
- Update to version 2.0.0
  * Papermill is now Python 3.5+ only
* Mon Nov 18 2019 Todd R <toddrme2178@gmail.com>
- Initial version
